@@ -1,13 +1,15 @@
 import logging
 from dataclasses import dataclass, field
 from datetime import datetime, date
-from typing import Optional, List
+from typing import Optional, List, Type
 from unittest.mock import ANY
 
 import pytest
 from pytest_mock import MockerFixture
 
-from dataclass_wizard import JSONSerializable
+from dataclass_wizard import JSONWizard
+from dataclass_wizard.bases import M
+from dataclass_wizard.bases_meta import BaseJSONWizardMeta
 from dataclass_wizard.enums import LetterCase, DateTimeTo
 from dataclass_wizard.errors import ParseError
 from dataclass_wizard.utils.type_conv import date_to_timestamp
@@ -27,9 +29,9 @@ def mock_meta_initializers(mocker: MockerFixture):
 
 
 @pytest.fixture
-def mock_meta_initialize(mocker: MockerFixture):
+def mock_bind_to(mocker: MockerFixture):
     return mocker.patch(
-        'dataclass_wizard.bases_meta.BaseJSONWizardMeta._meta_initialize')
+        'dataclass_wizard.bases_meta.BaseJSONWizardMeta.bind_to')
 
 
 @pytest.fixture
@@ -37,16 +39,100 @@ def mock_get_dumper(mocker: MockerFixture):
     return mocker.patch('dataclass_wizard.bases_meta.get_dumper')
 
 
+def test_merge_meta_with_or():
+    """We are able to merge two Meta classes using the __or__ method."""
+    class A(BaseJSONWizardMeta):
+        debug_enabled = True
+        key_transform_with_dump = 'CAMEL'
+        marshal_date_time_as = None
+        tag = None
+        json_key_to_field = {'k1': 'v1'}
+
+    class B(BaseJSONWizardMeta):
+        debug_enabled = False
+        key_transform_with_load = 'SNAKE'
+        marshal_date_time_as = DateTimeTo.TIMESTAMP
+        tag = 'My Test Tag'
+        json_key_to_field = {'k2': 'v2'}
+
+    # Merge the two Meta config together
+    merged_meta: M = A | B
+
+    # Assert we are a subclass of A, which subclasses from `BaseJSONWizardMeta`
+    assert issubclass(merged_meta, BaseJSONWizardMeta)
+    assert issubclass(merged_meta, A)
+    assert merged_meta is not A
+
+    # Assert Meta fields are merged from A and B as expected (with priority
+    # given to A)
+    assert 'CAMEL' == merged_meta.key_transform_with_dump == A.key_transform_with_dump
+    assert 'SNAKE' == merged_meta.key_transform_with_load == B.key_transform_with_load
+    assert None is merged_meta.marshal_date_time_as is A.marshal_date_time_as
+    assert True is merged_meta.debug_enabled is A.debug_enabled
+    # Assert that special attributes are only copied from A
+    assert None is merged_meta.tag is A.tag
+    assert {'k1': 'v1'} == merged_meta.json_key_to_field == A.json_key_to_field
+
+    # Assert A and B have not been mutated
+    assert A.key_transform_with_load is None
+    assert B.key_transform_with_load == 'SNAKE'
+    assert B.json_key_to_field == {'k2': 'v2'}
+    # Assert that Base class attributes have not been mutated
+    assert BaseJSONWizardMeta.key_transform_with_load is None
+    assert BaseJSONWizardMeta.json_key_to_field is None
+
+
+def test_merge_meta_with_and():
+    """We are able to merge two Meta classes using the __or__ method."""
+    class A(BaseJSONWizardMeta):
+        debug_enabled = True
+        key_transform_with_dump = 'CAMEL'
+        marshal_date_time_as = None
+        tag = None
+        json_key_to_field = {'k1': 'v1'}
+
+    class B(BaseJSONWizardMeta):
+        debug_enabled = False
+        key_transform_with_load = 'SNAKE'
+        marshal_date_time_as = DateTimeTo.TIMESTAMP
+        tag = 'My Test Tag'
+        json_key_to_field = {'k2': 'v2'}
+
+    # Merge the two Meta config together
+    merged_meta: M = A & B
+
+    # Assert we are a subclass of A, which subclasses from `BaseJSONWizardMeta`
+    assert issubclass(merged_meta, BaseJSONWizardMeta)
+    assert merged_meta is A
+
+    # Assert Meta fields are merged from A and B as expected (with priority
+    # given to A)
+    assert 'CAMEL' == merged_meta.key_transform_with_dump == A.key_transform_with_dump
+    assert 'SNAKE' == merged_meta.key_transform_with_load == B.key_transform_with_load
+    assert DateTimeTo.TIMESTAMP is merged_meta.marshal_date_time_as is A.marshal_date_time_as
+    assert False is merged_meta.debug_enabled is A.debug_enabled
+    # Assert that special attributes are copied from B
+    assert 'My Test Tag' == merged_meta.tag == A.tag
+    assert {'k2': 'v2'} == merged_meta.json_key_to_field == A.json_key_to_field
+
+    # Assert A has been mutated
+    assert A.key_transform_with_load == B.key_transform_with_load == 'SNAKE'
+    assert B.json_key_to_field == {'k2': 'v2'}
+    # Assert that Base class attributes have not been mutated
+    assert BaseJSONWizardMeta.key_transform_with_load is None
+    assert BaseJSONWizardMeta.json_key_to_field is None
+
+
 def test_meta_initializer_runs_as_expected(mock_log):
     """
-    Optional flags passed in when subclassing :class:`JSONSerializable.Meta`
+    Optional flags passed in when subclassing :class:`JSONWizard.Meta`
     are correctly applied as expected.
     """
 
     @dataclass
-    class MyClass(JSONSerializable):
+    class MyClass(JSONWizard):
 
-        class Meta(JSONSerializable.Meta):
+        class Meta(JSONWizard.Meta):
             debug_enabled = True
             json_key_to_field = {
                 '__all__': True,
@@ -108,15 +194,15 @@ def test_meta_initializer_runs_as_expected(mock_log):
 def test_json_key_to_field_when_add_is_a_falsy_value(mock_log):
     """
     The `json_key_to_field` attribute is specified when subclassing
-    :class:`JSONSerializable.Meta`, but the `__all__` field a falsy value.
+    :class:`JSONWizard.Meta`, but the `__all__` field a falsy value.
 
     Added for code coverage.
     """
 
     @dataclass
-    class MyClass(JSONSerializable):
+    class MyClass(JSONWizard):
 
-        class Meta(JSONSerializable.Meta):
+        class Meta(JSONWizard.Meta):
             debug_enabled = True
             json_key_to_field = {
                 '__all__': False,
@@ -153,9 +239,9 @@ def test_json_key_to_field_when_add_is_a_falsy_value(mock_log):
 def test_meta_config_is_not_implicitly_shared_between_dataclasses(mock_log):
 
     @dataclass
-    class MyFirstClass(JSONSerializable):
+    class MyFirstClass(JSONWizard):
 
-        class _(JSONSerializable.Meta):
+        class _(JSONWizard.Meta):
             debug_enabled = True
             marshal_date_time_as = DateTimeTo.TIMESTAMP
             key_transform_with_load = 'Camel'
@@ -164,7 +250,7 @@ def test_meta_config_is_not_implicitly_shared_between_dataclasses(mock_log):
         myStr: str
 
     @dataclass
-    class MySecondClass(JSONSerializable):
+    class MySecondClass(JSONWizard):
 
         my_str: Optional[str]
         my_date: date
@@ -232,39 +318,39 @@ def test_meta_initializer_is_called_when_meta_is_an_inner_class(
     Meta Initializer `dict` should be updated when `Meta` is an inner class.
     """
 
-    class _(JSONSerializable):
-        class _(JSONSerializable.Meta):
+    class _(JSONWizard):
+        class _(JSONWizard.Meta):
             debug_enabled = True
 
     mock_meta_initializers.__setitem__.assert_called_once()
 
 
 def test_meta_initializer_not_called_when_meta_is_not_an_inner_class(
-        mock_meta_initializers, mock_meta_initialize):
+        mock_meta_initializers, mock_bind_to):
     """
     Meta Initializer `dict` should *not* be updated when `Meta` has no outer
     class.
     """
 
-    class _(JSONSerializable.Meta):
+    class _(JSONWizard.Meta):
         debug_enabled = True
 
     mock_meta_initializers.__setitem__.assert_not_called()
-    mock_meta_initialize.assert_called_once_with(ANY, create=False)
+    mock_bind_to.assert_called_once_with(ANY, create=False)
 
 
 def test_meta_initializer_errors_when_key_transform_with_load_is_invalid(
         mock_log):
     """
     Test when an invalid value for the ``key_transform_with_load`` attribute
-    is specified when sub-classing from :class:`JSONSerializable.Meta`.
+    is specified when sub-classing from :class:`JSONWizard.Meta`.
 
     """
     with pytest.raises(ParseError):
 
         @dataclass
-        class _(JSONSerializable):
-            class Meta(JSONSerializable.Meta):
+        class _(JSONWizard):
+            class Meta(JSONWizard.Meta):
                 key_transform_with_load = 'Hello'
 
             my_str: Optional[str]
@@ -275,14 +361,14 @@ def test_meta_initializer_errors_when_key_transform_with_dump_is_invalid(
         mock_log):
     """
     Test when an invalid value for the ``key_transform_with_dump`` attribute
-    is specified when sub-classing from :class:`JSONSerializable.Meta`.
+    is specified when sub-classing from :class:`JSONWizard.Meta`.
 
     """
     with pytest.raises(ParseError):
 
         @dataclass
-        class _(JSONSerializable):
-            class Meta(JSONSerializable.Meta):
+        class _(JSONWizard):
+            class Meta(JSONWizard.Meta):
                 key_transform_with_dump = 'World'
 
             my_str: Optional[str]
@@ -293,14 +379,14 @@ def test_meta_initializer_errors_when_marshal_date_time_as_is_invalid(
         mock_log):
     """
     Test when an invalid value for the ``marshal_date_time_as`` attribute
-    is specified when sub-classing from :class:`JSONSerializable.Meta`.
+    is specified when sub-classing from :class:`JSONWizard.Meta`.
 
     """
     with pytest.raises(ParseError):
 
         @dataclass
-        class _(JSONSerializable):
-            class Meta(JSONSerializable.Meta):
+        class _(JSONWizard):
+            class Meta(JSONWizard.Meta):
                 marshal_date_time_as = 'iso'
 
             my_str: Optional[str]
@@ -316,8 +402,8 @@ def test_meta_initializer_is_noop_when_marshal_date_time_as_is_iso_format(
 
     """
     @dataclass
-    class _(JSONSerializable):
-        class Meta(JSONSerializable.Meta):
+    class _(JSONWizard):
+        class Meta(JSONWizard.Meta):
             marshal_date_time_as = 'ISO Format'
 
         my_str: Optional[str]
